@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2.5
 ###########################################################################
 ## Name: 	       SleepAnalyser
 ## Description:  Sleep Analyser records your movement during your sleep. It is able to visualise it on a graph to show
@@ -20,6 +20,7 @@
 #import array
 #import string
 
+
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
@@ -80,6 +81,10 @@ from Ui_AdditionalInfoWindow import *
 #print ar
 #exit
 
+
+
+
+
 ###########################################################################
 ## Main function
 ##############o#############################################################
@@ -582,6 +587,8 @@ class frmStartWindow(QMainWindow):
 
 
 
+
+
     ###########################################################################
     ## Show the collectring window (her the data gets visualised during the logging)
     ###########################################################################
@@ -1254,9 +1261,9 @@ class frmViewWindow(QMainWindow):
     ##
     ###########################################################################
     def DeleteRecord(self): ##(Class ViewWindow)
-        self.ui.lblStatus.setText("Delete file...")
+        self.ui.lblStatus.setText(_("Delete record..."))
         self.ui.lblStatus.show()
-        reply = QtGui.QMessageBox.question(self, _("Delete Record?"), _("Are you sure you want to delete this record:")+"\n"+data.logfilename, QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+        reply = QtGui.QMessageBox.question(self, _("Delete record?"), _("Are you sure you want to delete this record:")+"\n"+data.logfilename, QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
         if reply == QtGui.QMessageBox.Yes:
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)
@@ -2170,6 +2177,26 @@ def GenerateStatisticsBitmap(self):
 #    self.ui.CanvasWidget.hide()
 #    self.ui.CanvasWidget.show()
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 ###########################################################################
 main() # Now we can start it.
+
